[Mpuls-commits] r1683 - in wasko/branches/2.0: . jmdweb jmdweb/controllers jmdweb/converter jmdweb/lib jmdweb/model jmdweb/model/io jmdweb/tests/functional

scm-commit@wald.intevation.org scm-commit at wald.intevation.org
Tue Feb 23 12:21:10 CET 2010


Author: torsten
Date: 2010-02-23 12:21:01 +0100 (Tue, 23 Feb 2010)
New Revision: 1683

Added:
   wasko/branches/2.0/jmdweb/
Modified:
   wasko/branches/2.0/ChangeLog
   wasko/branches/2.0/jmdweb/controllers/administration.py
   wasko/branches/2.0/jmdweb/controllers/case.py
   wasko/branches/2.0/jmdweb/controllers/case_overview.py
   wasko/branches/2.0/jmdweb/controllers/caseappointment.py
   wasko/branches/2.0/jmdweb/controllers/casedocument.py
   wasko/branches/2.0/jmdweb/controllers/caselifetime.py
   wasko/branches/2.0/jmdweb/controllers/evaluate.py
   wasko/branches/2.0/jmdweb/controllers/phase.py
   wasko/branches/2.0/jmdweb/controllers/statement.py
   wasko/branches/2.0/jmdweb/controllers/waska.py
   wasko/branches/2.0/jmdweb/converter/wasko_v1v2.py
   wasko/branches/2.0/jmdweb/lib/app_globals.py
   wasko/branches/2.0/jmdweb/lib/excel.py
   wasko/branches/2.0/jmdweb/model/appointment.py
   wasko/branches/2.0/jmdweb/model/case.py
   wasko/branches/2.0/jmdweb/model/casexml.py
   wasko/branches/2.0/jmdweb/model/data.py
   wasko/branches/2.0/jmdweb/model/exprtree.py
   wasko/branches/2.0/jmdweb/model/io/document.py
   wasko/branches/2.0/jmdweb/model/io/factories.py
   wasko/branches/2.0/jmdweb/model/phases.py
   wasko/branches/2.0/jmdweb/model/phases_factory.py
   wasko/branches/2.0/jmdweb/tests/functional/test_administration.py
   wasko/branches/2.0/jmdweb/tests/functional/test_appointment.py
   wasko/branches/2.0/jmdweb/tests/functional/test_case.py
   wasko/branches/2.0/jmdweb/tests/functional/test_case_overview.py
   wasko/branches/2.0/jmdweb/tests/functional/test_caseappointment.py
   wasko/branches/2.0/jmdweb/tests/functional/test_casedocument.py
   wasko/branches/2.0/jmdweb/tests/functional/test_document.py
   wasko/branches/2.0/jmdweb/tests/functional/test_logbook.py
   wasko/branches/2.0/jmdweb/tests/functional/test_phase.py
   wasko/branches/2.0/jmdweb/tests/functional/test_usersettings.py
   wasko/branches/2.0/jmdweb/tests/functional/test_waska.py
Log:
Copied jmdweb from waskaweb


Modified: wasko/branches/2.0/ChangeLog
===================================================================
--- wasko/branches/2.0/ChangeLog	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/ChangeLog	2010-02-23 11:21:01 UTC (rev 1683)
@@ -1,3 +1,7 @@
+2010-02-23  Torsten Irländer <torsten.irlaender at intevation.de>
+
+	* jmdweb: New. copied from waskaweb. Adapted imports to jmdweb. 
+
 2010-02-22  Bernhard Herzog  <bh at intevation.de>
 
 	* INSTALL: Update documentation for the field-specific settings.

Copied: wasko/branches/2.0/jmdweb (from rev 1682, wasko/branches/2.0/waskaweb)


Property changes on: wasko/branches/2.0/jmdweb
___________________________________________________________________
Name: svn:ignore
   + *.pyc

Name: svn:mergeinfo
   + 

Modified: wasko/branches/2.0/jmdweb/controllers/administration.py
===================================================================
--- wasko/branches/2.0/waskaweb/controllers/administration.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/controllers/administration.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -39,9 +39,9 @@
 from mpulsweb.model.user import UserObject, UserListObject
 from mpulsweb.controllers.administration import AdministrationController as BaseAdministrationController
 
-from waskaweb.lib.base import c, redirect_to, render, request, session
-from waskaweb.lib.validators import DeleteUserHelperForm
-from waskaweb.model.case import CaseOverview, CaseBundle
+from jmdweb.lib.base import c, redirect_to, render, request, session
+from jmdweb.lib.validators import DeleteUserHelperForm
+from jmdweb.model.case import CaseOverview, CaseBundle
 
 log = logging.getLogger(__name__)
 

Modified: wasko/branches/2.0/jmdweb/controllers/case.py
===================================================================
--- wasko/branches/2.0/waskaweb/controllers/case_overview.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/controllers/case_overview.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -36,15 +36,15 @@
 from paste.httpexceptions import HTTPNotFound
 
 from mpulsweb.lib.base import c, h, render, request, session
-from waskaweb.lib.base import BaseController
+from jmdweb.lib.base import BaseController
 import mpulsweb.lib.helper.filters as F
-from waskaweb.lib.validators import SearchCaseForm, BundleActionForm, \
+from jmdweb.lib.validators import SearchCaseForm, BundleActionForm, \
      SetBundleEditorForm, SetBundleStandinForm, CasePartSelectionForm
 from mpulsweb.lib.security import checkRole
-from waskaweb.lib.search import INCONSISTENCY_CHECK_AFTER
-from waskaweb.lib.exportselection import CasePartsSelection
+from jmdweb.lib.search import INCONSISTENCY_CHECK_AFTER
+from jmdweb.lib.exportselection import CasePartsSelection
 
-from waskaweb.model.case import CaseOverview, CaseBundle
+from jmdweb.model.case import CaseOverview, CaseBundle
 from mpulsweb.model.user import UserListObject, UserObject, UserGroupList
 
 

Modified: wasko/branches/2.0/jmdweb/controllers/caseappointment.py
===================================================================
--- wasko/branches/2.0/waskaweb/controllers/caseappointment.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/controllers/caseappointment.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -20,11 +20,11 @@
      EDIT_APPOINT_NOTIFICATION_SUCCESS, \
      EDIT_APPOINT_NOTIFICATION_TEXT_SUCCESS
 
-from waskaweb.lib.base import BaseController, render
-from waskaweb.lib.validators import CreateAppointmentForm
-from waskaweb.model.appointment import CaseAppointmentOverview, \
+from jmdweb.lib.base import BaseController, render
+from jmdweb.lib.validators import CreateAppointmentForm
+from jmdweb.model.appointment import CaseAppointmentOverview, \
      CaseAppointmentFactory, CaseReminderOverview
-from waskaweb.controllers.case import checkPrivacyStatement
+from jmdweb.controllers.case import checkPrivacyStatement
 
 log = logging.getLogger(__name__)
 
@@ -112,7 +112,7 @@
         # confirmed is True because usually this controller is used when
         # the privacy statement nag-screen has already been shown.
         # Also, it was the default value used in the original routing in
-        # waskaweb/config/routing.py.
+        # jmdweb/config/routing.py.
         # FIXME: do we really need the checkPrivacyStatement decorator here?
         factory = CaseAppointmentFactory()
         id = self._checkInt(id)

Modified: wasko/branches/2.0/jmdweb/controllers/casedocument.py
===================================================================
--- wasko/branches/2.0/waskaweb/controllers/casedocument.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/controllers/casedocument.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -10,7 +10,7 @@
 import mpulsweb.lib.helpers as h
 from mpulsweb.model.document import Document, deleteDocument
 
-from waskaweb.lib.base import BaseController, render
+from jmdweb.lib.base import BaseController, render
 
 
 log = logging.getLogger(__name__)

Modified: wasko/branches/2.0/jmdweb/controllers/caselifetime.py
===================================================================
--- wasko/branches/2.0/waskaweb/controllers/caselifetime.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/controllers/caselifetime.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -14,13 +14,13 @@
 import mpulsweb.lib.helpers as h
 from mpulsweb.model.logbook import Logbook, LogbookEntry
 
-from waskaweb.lib.validators import \
+from jmdweb.lib.validators import \
      ExtraTimeFormValidator1, ExtraTimeFormValidator2, \
      ReopenFormValidator1, ReopenFormValidator1abgel, \
      ReopenFormValidator2, ReopenFormValidator2abgel, \
      RenewFormValidator
 
-from waskaweb.lib.base import BaseController 
+from jmdweb.lib.base import BaseController 
 
 log = logging.getLogger(__name__)
 

Modified: wasko/branches/2.0/jmdweb/controllers/evaluate.py
===================================================================
--- wasko/branches/2.0/waskaweb/controllers/evaluate.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/controllers/evaluate.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -12,7 +12,7 @@
 from mpulsweb.lib.db import db
 from mpulsweb.lib.helpers import format_date, get_phasesuccessors 
 
-from waskaweb.lib.validators import EvaluationFormValidator
+from jmdweb.lib.validators import EvaluationFormValidator
 log = logging.getLogger(__name__)
 
 def get_configfile(id):

Modified: wasko/branches/2.0/jmdweb/controllers/phase.py
===================================================================
--- wasko/branches/2.0/waskaweb/controllers/phase.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/controllers/phase.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -5,8 +5,8 @@
 
 from mpulsweb.lib.security import checkRole
 
-from waskaweb.lib.base import BaseController, h, render, request
-from waskaweb.model.phase import PhaseFactory
+from jmdweb.lib.base import BaseController, h, render, request
+from jmdweb.model.phase import PhaseFactory
 
 SET_PHASE_NOTIFICATION_SUCCESS = u"""Phase gewechselt!"""
 SET_PHASE_NOTIFICATION_TEXT_SUCCESS= u"""\

Modified: wasko/branches/2.0/jmdweb/controllers/statement.py
===================================================================
--- wasko/branches/2.0/waskaweb/controllers/statement.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/controllers/statement.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -34,12 +34,12 @@
 from mpulsweb.lib.base import c, h, redirect_to, render, session
 from mpulsweb.lib.security import checkRole
 
-from waskaweb.lib.base import BaseController 
-from waskaweb.lib.search import INCONSISTENCY_CHECK_AFTER
+from jmdweb.lib.base import BaseController 
+from jmdweb.lib.search import INCONSISTENCY_CHECK_AFTER
 
-from waskaweb.model.phase_transition import PHASE_DESCRIPTIONS
+from jmdweb.model.phase_transition import PHASE_DESCRIPTIONS
 
-from waskaweb.controllers.case import ANONYMIZE_CONFIRM, \
+from jmdweb.controllers.case import ANONYMIZE_CONFIRM, \
      MARKANONYMIZE_CONFIRM_TEXT, MARKANONYMIZE_SUCCESS, \
      MARKANONYMIZE_SUCCESS_TEXT, \
      MARKANONYMIZE_INCOMPLETE_PHASE_FAILED_TEXT,\

Modified: wasko/branches/2.0/jmdweb/controllers/waska.py
===================================================================
--- wasko/branches/2.0/waskaweb/controllers/waska.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/controllers/waska.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -36,10 +36,10 @@
     get_global_appointments
 from mpulsweb.controllers.auth  import AuthController
 
-from waskaweb.lib.base import BaseController, c, g, h, redirect_to, render, \
+from jmdweb.lib.base import BaseController, c, g, h, redirect_to, render, \
      request, response, session
 from mpulsweb.lib.security import checkRole
-from waskaweb.model.appointment import MaxSaveTimeReminderOverview, \
+from jmdweb.model.appointment import MaxSaveTimeReminderOverview, \
      CaseAppointmentOverview, GlobalAppointmentOverview, CaseReminderOverview
 
 

Modified: wasko/branches/2.0/jmdweb/converter/wasko_v1v2.py
===================================================================
--- wasko/branches/2.0/waskaweb/converter/wasko_v1v2.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/converter/wasko_v1v2.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -40,7 +40,7 @@
 #      geschw_alt_c = geschw_w_c  + geschw_m_c
 #      geschw_alt_d = geschw_w_d  + geschw_m_d
 
-from waskaweb.lib.xmlhelper import decode_int
+from jmdweb.lib.xmlhelper import decode_int
 
 
 def getConverterFactory():

Modified: wasko/branches/2.0/jmdweb/lib/app_globals.py
===================================================================
--- wasko/branches/2.0/waskaweb/lib/app_globals.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/lib/app_globals.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -2,7 +2,7 @@
 
 from mpulsweb.lib.app_globals import Globals as MPulsGlobals
 
-from waskaweb.model.case import Case, CaseFactory
+from jmdweb.model.case import Case, CaseFactory
 
 
 class Globals(MPulsGlobals):

Modified: wasko/branches/2.0/jmdweb/lib/excel.py
===================================================================
--- wasko/branches/2.0/waskaweb/lib/excel.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/lib/excel.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -30,7 +30,7 @@
 
 from types import StringTypes, IntType, LongType
 
-from waskaweb.model.data     import WidgetCollector
+from jmdweb.model.data     import WidgetCollector
 
 from exportselection import CasePartsSelection, SelectorFactory
 

Modified: wasko/branches/2.0/jmdweb/model/appointment.py
===================================================================
--- wasko/branches/2.0/waskaweb/model/appointment.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/model/appointment.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -31,7 +31,7 @@
 from mpulsweb.model.appointment import *
 from mpulsweb.model.agencysettings import Agency
 
-from waskaweb.model.case import CaseOverview
+from jmdweb.model.case import CaseOverview
 
 GET_OLDACTIVE_CASES_4_ADMIN = """
 SELECT m.id, s.zugriff, getLastCaseAppointment(m.id) AS last_date

Modified: wasko/branches/2.0/jmdweb/model/case.py
===================================================================
--- wasko/branches/2.0/waskaweb/model/casexml.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/model/casexml.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -28,19 +28,19 @@
 # Sascha L. Teichmann <teichmann at intevation.de>
 #
 
-from waskaweb.lib.uuid import uuid4
+from jmdweb.lib.uuid import uuid4
 
 from mpulsweb.lib.db   import db
 
-from waskaweb.lib.xmlhelper import \
+from jmdweb.lib.xmlhelper import \
     decode_int,                    \
     decode_date,                   \
     decode_iso_datetime,           \
     StackedLoader
 
-import waskaweb.model.data as data
+import jmdweb.model.data as data
 
-from waskaweb.model.semantic import checkAndConvert, SematicError
+from jmdweb.model.semantic import checkAndConvert, SematicError
 
 from xml.sax          import make_parser
 from xml.sax.saxutils import escape

Modified: wasko/branches/2.0/jmdweb/model/data.py
===================================================================
--- wasko/branches/2.0/waskaweb/model/data.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/model/data.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -241,8 +241,8 @@
                 if not os.path.isabs(fname) and self.path:
                     fname = os.path.join(self.path, fname)
                 try: # TODO: This loading code should be else where!
-                    import waskaweb.model.io.document
-                    document = waskaweb.model.io.document.openDocument(fname)
+                    import jmdweb.model.io.document
+                    document = jmdweb.model.io.document.openDocument(fname)
                     self.choice = document.findByClassAndName(ChoiceNode)
                 except Exception, inst:
                     print >> sys.stderr, repr(inst)

Modified: wasko/branches/2.0/jmdweb/model/exprtree.py
===================================================================
--- wasko/branches/2.0/waskaweb/model/exprtree.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/model/exprtree.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -37,7 +37,7 @@
 from datetime import date
 from types    import StringTypes
 
-from waskaweb.model import UNKNOWN_DATE, UNKNOWN_INT, UNKNOWN_STR
+from jmdweb.model import UNKNOWN_DATE, UNKNOWN_INT, UNKNOWN_STR
 
 FLT_RE = re.compile(r'^([-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?)$')
 INT_RE = re.compile(r'^([-+]?[0-9]+)$')

Modified: wasko/branches/2.0/jmdweb/model/io/document.py
===================================================================
--- wasko/branches/2.0/waskaweb/model/io/document.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/model/io/document.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -35,8 +35,8 @@
 import codecs
 
 from factories import DocumentFactory, SimpleCreator, NodeComponentFactory, NodeFactory
-from waskaweb.model.nodecomponents import RootNode, CaseNode, LogbookNode, Document, Leaf, Node
-from waskaweb.model.data           import *
+from jmdweb.model.nodecomponents import RootNode, CaseNode, LogbookNode, Document, Leaf, Node
+from jmdweb.model.data           import *
 
 DOCUMENT_TAG        = u"document"
 CASE_TAG            = u"case"

Modified: wasko/branches/2.0/jmdweb/model/io/factories.py
===================================================================
--- wasko/branches/2.0/waskaweb/model/io/factories.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/model/io/factories.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -30,7 +30,7 @@
 
 from parser import Factory, Creator
 
-from waskaweb.model.nodecomponents import Document
+from jmdweb.model.nodecomponents import Document
 
 class SimpleCreator(Creator):
 

Modified: wasko/branches/2.0/jmdweb/model/phases.py
===================================================================
--- wasko/branches/2.0/waskaweb/model/phases.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/model/phases.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -28,7 +28,7 @@
 # Sascha L. Teichmann <sascha.teichmann at intevation.de>
 #
 
-from waskaweb.model.phase_transition import \
+from jmdweb.model.phase_transition import \
     phase_neighbors, phase_symbol, phase_description, phase_predecessors_path, phase_successors_path
 
 class Phase:

Modified: wasko/branches/2.0/jmdweb/model/phases_factory.py
===================================================================
--- wasko/branches/2.0/waskaweb/tests/functional/test_administration.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/tests/functional/test_administration.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -21,7 +21,7 @@
 # within the programme Kompetenzagenturen (Durchfuehrungsphase) funded by
 # the Bundesministerium fuer Familie, Senioren, Frauen und Jugend and 
 # European Social Fund resources.
-from waskaweb.tests import *
+from jmdweb.tests import *
 
 class TestAdministrationController(TestController):
 

Modified: wasko/branches/2.0/jmdweb/tests/functional/test_appointment.py
===================================================================
--- wasko/branches/2.0/waskaweb/tests/functional/test_appointment.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/tests/functional/test_appointment.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -21,7 +21,7 @@
 # within the programme Kompetenzagenturen (Durchfuehrungsphase) funded by
 # the Bundesministerium fuer Familie, Senioren, Frauen und Jugend and 
 # European Social Fund resources.
-from waskaweb.tests import *
+from jmdweb.tests import *
 
 class TestAppointmentController(TestController):
 

Modified: wasko/branches/2.0/jmdweb/tests/functional/test_case.py
===================================================================
--- wasko/branches/2.0/waskaweb/tests/functional/test_case.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/tests/functional/test_case.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -21,7 +21,7 @@
 # within the programme Kompetenzagenturen (Durchfuehrungsphase) funded by
 # the Bundesministerium fuer Familie, Senioren, Frauen und Jugend and 
 # European Social Fund resources.
-from waskaweb.tests import *
+from jmdweb.tests import *
 
 class TestCaseController(TestController):
 

Modified: wasko/branches/2.0/jmdweb/tests/functional/test_case_overview.py
===================================================================
--- wasko/branches/2.0/waskaweb/tests/functional/test_case_overview.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/tests/functional/test_case_overview.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -21,7 +21,7 @@
 # within the programme Kompetenzagenturen (Durchfuehrungsphase) funded by
 # the Bundesministerium fuer Familie, Senioren, Frauen und Jugend and 
 # European Social Fund resources.
-from waskaweb.tests import *
+from jmdweb.tests import *
 
 class TestCaseOverviewController(TestController):
 

Modified: wasko/branches/2.0/jmdweb/tests/functional/test_caseappointment.py
===================================================================
--- wasko/branches/2.0/waskaweb/tests/functional/test_caseappointment.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/tests/functional/test_caseappointment.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -1,4 +1,4 @@
-from waskaweb.tests import *
+from jmdweb.tests import *
 
 class TestCaseappointmentController(TestController):
 

Modified: wasko/branches/2.0/jmdweb/tests/functional/test_casedocument.py
===================================================================
--- wasko/branches/2.0/waskaweb/tests/functional/test_casedocument.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/tests/functional/test_casedocument.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -1,4 +1,4 @@
-from waskaweb.tests import *
+from jmdweb.tests import *
 
 class TestCasedocumentController(TestController):
 

Modified: wasko/branches/2.0/jmdweb/tests/functional/test_document.py
===================================================================
--- wasko/branches/2.0/waskaweb/tests/functional/test_document.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/tests/functional/test_document.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -21,7 +21,7 @@
 # within the programme Kompetenzagenturen (Durchfuehrungsphase) funded by
 # the Bundesministerium fuer Familie, Senioren, Frauen und Jugend and 
 # European Social Fund resources.
-from waskaweb.tests import *
+from jmdweb.tests import *
 
 class TestDocumentController(TestController):
 

Modified: wasko/branches/2.0/jmdweb/tests/functional/test_logbook.py
===================================================================
--- wasko/branches/2.0/waskaweb/tests/functional/test_logbook.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/tests/functional/test_logbook.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -21,7 +21,7 @@
 # within the programme Kompetenzagenturen (Durchfuehrungsphase) funded by
 # the Bundesministerium fuer Familie, Senioren, Frauen und Jugend and 
 # European Social Fund resources.
-from waskaweb.tests import *
+from jmdweb.tests import *
 
 class TestLogbookController(TestController):
 

Modified: wasko/branches/2.0/jmdweb/tests/functional/test_phase.py
===================================================================
--- wasko/branches/2.0/waskaweb/tests/functional/test_phase.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/tests/functional/test_phase.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -1,4 +1,4 @@
-from waskaweb.tests import *
+from jmdweb.tests import *
 
 class TestPhaseController(TestController):
 

Modified: wasko/branches/2.0/jmdweb/tests/functional/test_usersettings.py
===================================================================
--- wasko/branches/2.0/waskaweb/tests/functional/test_usersettings.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/tests/functional/test_usersettings.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -21,7 +21,7 @@
 # within the programme Kompetenzagenturen (Durchfuehrungsphase) funded by
 # the Bundesministerium fuer Familie, Senioren, Frauen und Jugend and 
 # European Social Fund resources.
-from waskaweb.tests import *
+from jmdweb.tests import *
 
 class TestUsersettingsController(TestController):
 

Modified: wasko/branches/2.0/jmdweb/tests/functional/test_waska.py
===================================================================
--- wasko/branches/2.0/waskaweb/tests/functional/test_waska.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/tests/functional/test_waska.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -21,7 +21,7 @@
 # within the programme Kompetenzagenturen (Durchfuehrungsphase) funded by
 # the Bundesministerium fuer Familie, Senioren, Frauen und Jugend and 
 # European Social Fund resources.
-from waskaweb.tests import *
+from jmdweb.tests import *
 
 class TestWaskaController(TestController):
 



More information about the Mpuls-commits mailing list
--- wasko/branches/2.0/waskaweb/controllers/case.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/controllers/case.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -50,25 +50,25 @@
 
 from mpulsweb.controllers.formularpage import convert2dic, get_rendered_page
 
-from waskaweb.lib.base import BaseController
-from waskaweb.lib.search import INCONSISTENCY_CHECK_AFTER
-#from waskaweb.lib.xmlimport import importFromXML
-from waskaweb.lib.validators import NewCaseForm, SetStandinForm, \
+from jmdweb.lib.base import BaseController
+from jmdweb.lib.search import INCONSISTENCY_CHECK_AFTER
+#from jmdweb.lib.xmlimport import importFromXML
+from jmdweb.lib.validators import NewCaseForm, SetStandinForm, \
      SetEditorForm, WiederaufnahmeCaseForm, \
      NeuaufnahmeCaseForm
 
-from waskaweb.model.statement import PrivacyStatement
-from waskaweb.model.case import Agency, SessionCase
-#from waskaweb.model.casexml import import_xml, XMLImportException
-from waskaweb.model.data import DateLeaf, IntLeaf, TextLeaf, RadioNode, \
+from jmdweb.model.statement import PrivacyStatement
+from jmdweb.model.case import Agency, SessionCase
+#from jmdweb.model.casexml import import_xml, XMLImportException
+from jmdweb.model.data import DateLeaf, IntLeaf, TextLeaf, RadioNode, \
      ChoiceNode
-from waskaweb.model.phases_factory import RequiredFields
-from waskaweb.model.phase_transition import phase_symbol, phase_start, \
+from jmdweb.model.phases_factory import RequiredFields
+from jmdweb.model.phase_transition import phase_symbol, phase_start, \
      PHASE_DESCRIPTIONS, CLEAR_START, CLEAR_ENDE, CM_ENDE, NB_ENDE
 
-from waskaweb.controllers.caselifetime import DataSaveException
+from jmdweb.controllers.caselifetime import DataSaveException
 
-from waskaweb.converter.wasko_v1v2 import WaskoV1V2
+from jmdweb.converter.wasko_v1v2 import WaskoV1V2
 
 
 log = logging.getLogger(__name__)

Modified: wasko/branches/2.0/jmdweb/controllers/case_overview.py
===================================================================
--- wasko/branches/2.0/waskaweb/model/case.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/model/case.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -49,15 +49,15 @@
 from mpulsweb.model.document import listDocuments
 from mpulsweb.model.case import MpulsCase, MpulsCaseFactory
 
-from waskaweb.lib.search import CaseSearch
-#from waskaweb.lib.csv import exportAsCSV
-#from waskaweb.lib.excel import exportAsXLS
-#from waskaweb.lib.xmlexport import exportAsXML
+from jmdweb.lib.search import CaseSearch
+#from jmdweb.lib.csv import exportAsCSV
+#from jmdweb.lib.excel import exportAsXLS
+#from jmdweb.lib.xmlexport import exportAsXML
 
-from waskaweb.model.statement import PrivacyStatement, DiscretionStatement
-from waskaweb.model.phase_transition import phase_description, phase_end, \
+from jmdweb.model.statement import PrivacyStatement, DiscretionStatement
+from jmdweb.model.phase_transition import phase_description, phase_end, \
      CM_START, CLEAR_START, CLEAR_ENDE
-from waskaweb.model.phases_factory import RequiredFields
+from jmdweb.model.phases_factory import RequiredFields
 
 
 log = logging.getLogger(__name__)

Modified: wasko/branches/2.0/jmdweb/model/casexml.py
===================================================================
--- wasko/branches/2.0/waskaweb/model/phases_factory.py	2010-02-22 19:13:38 UTC (rev 1682)
+++ wasko/branches/2.0/jmdweb/model/phases_factory.py	2010-02-23 11:21:01 UTC (rev 1683)
@@ -31,11 +31,11 @@
 from xml.sax.saxutils import quoteattr
 from cgi import escape
 
-from waskaweb.model.phases import Phase, PhasePair
-from waskaweb.model.phase_transition import CLEAR_ENDE, CLEAR_START, CM_ENDE, \
+from jmdweb.model.phases import Phase, PhasePair
+from jmdweb.model.phase_transition import CLEAR_ENDE, CLEAR_START, CM_ENDE, \
      CM_START, NB_ENDE, NB_START, phase_predecessors, phase_symbol
 
 #from waskaweb.model.data import PageNode
 
 
 PAIRS = (
@@ -31,11 +31,11 @@
      CM_START, NB_ENDE, NB_START, phase_predecessors, phase_symbol
 
-#from waskaweb.model.data import PageNode
+#from jmdweb.model.data import PageNode
 
 

Modified: wasko/branches/2.0/jmdweb/tests/functional/test_administration.py
===================================================================